import React from 'react';
import PropTypes from 'prop-types';
import moment from 'moment';
import { Table, Input, Icon } from 'antd';
import { connect } from 'dva';
import config from '../../../../utils/config';
import styles from './list.less';

const columns = [{
  title: '流程',
  dataIndex: 'pName',
  key: 'pName',
}, {
  title: '任务',
  dataIndex: 'nName',
  key: 'nName',
}, {
  title: '状态',
  dataIndex: 'state',
  key: 'state',
}, {
  title: '日期',
  dataIndex: 'date',
  key: 'date',
  render(date) {
    return date.format(config.defaultDateTimeFormat);
  },
}, {
  title: '期限',
  dataIndex: 'deadline',
  key: 'deadline',
  render(deadline) {
    const now = moment();
    const late = deadline.diff(now, 'days', true);
    if (late < 0) {
      const style = {
        color: '#f04134',
      };
      return <span style={style}>{ `超时 ${deadline.from(now, true)}` }</span>;
    } else if (late < 1) {
      const style = {
        color: '#ffbf00',
      };
      return <span style={style}>{ `仅剩 ${deadline.to(now, true)}` }</span>;
    } else {
      const style = {
        color: '#00a854',
      };
      return <span style={style}>{ `还剩 ${deadline.to(now, true)}` }</span>;
    }
  },
}];

const psz = 10;

class List extends React.Component {

  constructor(props, context) {
    super(props, context);
    this.onSearch = this::this.onSearch;
  }
  componentDidMount() {
    this.props.dispatch({ type: 'task/fetchTasks', payload: { pst: 0, psz } });
  }
  onSearch(value) {
    console.log(value);
  }
  render() {
    const { list, pageStart, pageSize, num } = this.props.task;
    const dispatch = this.props.dispatch;
    const tableProps = {
      dataSource: list,
      columns,
      loading: this.props.loading.effects['task/fetchTasks'],
      pagination: {
        current: (pageStart / pageSize) | 0,
        total: num,
        pageSize,
      },
      onChange(pagination) {
        const psz = pagination.pageSize; // eslint-disable-line no-shadow
        const pst = pagination.current * psz;
        dispatch({ type: 'task/fetchTasks', payload: { pst, psz } });
      },
    };
    return (
      <div className={styles.wrapper}>
        <div className={styles.container}>
          <div className={styles.search}>
            <Input.Search onSearch={this.onSearch} />
          </div>
          <Table {...tableProps} />
        </div>
      </div>
    );
  }

}

List.propTypes = {
  task: PropTypes.object.isRequired,
};

export default connect(({ task, loading }) => ({ task, loading }))(List);
